/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file msg.h
 *
 * @type subsystem
 *
 * @description
 *
 * The msg subsystem is an interface to the MessageTrans module.
 * It maintains a single messages file in memory.
 */

#ifndef __rov_msgtrans
#define __rov_msgtrans


#ifdef __cplusplus
extern "C"
{
#endif

#ifndef __rov_main
#include "main.h"
#endif

/**
 * Read a messages file.
 * @param file_name the name of the messages file.
 * @return non-zero for success.
 */
int msg_read(char *file_name);

/**
 * Lookup a string with four replacement variables.
 * @param token the messages string to look up.
 * @param rep1 the first replacement.
 * @param rep2 the second replacement.
 * @param rep3 the third replacement.
 * @param rep4 the fourth replacement.
 * @return the string with replacements.
 * @note The string is held in a static area of memory, and must
 * be copied before calling another msg_lookup function.
 * @see msg_lookup3()
 * @see msg_lookup2()
 * @see msg_lookup1()
 * @see msg_lookup()
 * @see msg_lookuprom()
 * @see msg_lookupbuffer()
 * @see msg_lookupfull()
 */
char *msg_lookup4(char *token,
		  char *rep1,
		  char *rep2,
		  char *rep3,
		  char *rep4);

/**
 * Lookup a string with three replacement variables.
 * @param token the messages string to look up.
 * @param rep1 the first replacement.
 * @param rep2 the second replacement.
 * @param rep3 the third replacement.
 * @return the string with replacements.
 * @note The string is held in a static area of memory, and must
 * be copied before calling another msg_lookup function.
 * @see msg_lookup4()
 * @see msg_lookup2()
 * @see msg_lookup1()
 * @see msg_lookup()
 * @see msg_lookuprom()
 * @see msg_lookupbuffer()
 * @see msg_lookupfull()
 */
char *msg_lookup3(char *token,
		  char *rep1,
		  char *rep2,
		  char *rep3);

/**
 * Lookup a string with two replacement variables.
 * @param token the messages string to look up.
 * @param rep1 the first replacement.
 * @param rep2 the second replacement.
 * @return the string with replacements.
 * @note The string is held in a static area of memory, and must
 * be copied before calling another msg_lookup function.
 * @see msg_lookup4()
 * @see msg_lookup3()
 * @see msg_lookup1()
 * @see msg_lookup()
 * @see msg_lookuprom()
 * @see msg_lookupbuffer()
 * @see msg_lookupfull()
 */
char *msg_lookup2(char *token,
		  char *rep1,
		  char *rep2);

/**
 * Lookup a string with one replacement variable.
 * @param token the messages string to look up.
 * @param rep the replacement.
 * @return the string with replacements.
 * @note The string is held in a static area of memory, and must
 * be copied before calling another msg_lookup function.
 * @see msg_lookup4()
 * @see msg_lookup3()
 * @see msg_lookup2()
 * @see msg_lookup()
 * @see msg_lookuprom()
 * @see msg_lookupbuffer()
 * @see msg_lookupfull()
 */
char *msg_lookup1(char *token, char *rep);

/**
 * Lookup a string with no replacement variables.
 * @param token the messages string to look up.
 * @return the string with replacements.
 * @note The string is held in a static area of memory, and must
 * be copied before calling another msg_lookup function.
 * @see msg_lookup4()
 * @see msg_lookup3()
 * @see msg_lookup2()
 * @see msg_lookup1()
 * @see msg_lookuprom()
 * @see msg_lookupbuffer()
 * @see msg_lookupfull()
 */
char *msg_lookup(char *token);

/**
 * Lookup a string but do not copy.
 * @param token the messages string to look up.
 * @note Unlike other msg_lookup calls, this call returns
 * the looked up string as a pointer into the messages file
 * itself, which must not be edited. This means that if you
 * use this, you must be able to cope with ctrl terminated
 * strings.
 * @see msg_lookup4()
 * @see msg_lookup3()
 * @see msg_lookup2()
 * @see msg_lookup1()
 * @see msg_lookup()
 * @see msg_lookupbuffer()
 * @see msg_lookupfull()
 */
char *msg_lookuprom(char *token);

/**
 * Lookup a string and copy to a buffer.
 * @param token the messages string to look up.
 * @param buffer the buffer to store the result in.
 * @see msg_lookup4()
 * @see msg_lookup3()
 * @see msg_lookup2()
 * @see msg_lookup1()
 * @see msg_lookup()
 * @see msg_lookuprom()
 * @see msg_lookupfull()
 */
char *msg_lookupbuffer(char *token,
		       char *buffer);

/**
 * Lookup a string with four replacement variables.
 * @param token the messages string to look up.
 * @param buffer the buffer to store the result.
 * @param blen the buffer length.
 * @param rep1 the first replacement.
 * @param rep2 the second replacement.
 * @param rep3 the third replacement.
 * @param rep4 the fourth replacement.
 * @return the string with replacements.
 * @note The string is held in a static area of memory, and must
 * be copied before calling another msg_lookup function.
 * @see msg_lookup3()
 * @see msg_lookup2()
 * @see msg_lookup1()
 * @see msg_lookup()
 * @see msg_lookuprom()
 * @see msg_lookupbuffer()
 */
char *msg_lookupfull(char *token,
		     char *buffer,
		     int blen,
		     char *rep1,
		     char *rep2,
		     char *rep3,
		     char *rep4);


#ifdef __cplusplus
}
#endif

#endif
